@@ -24,8 +24,8 @@ def main():
     #gene selection
     parser.add_argument("-c", "--cds", help="search for a given list of gene, exp: COX1 COX2 COX3, accepts regex", nargs="*")
     #file output
-    parser.add_argument("-T", "--TAXIDS", help='write a text file listing all the accession numbers and their related TaxIDs', action="store_true")
-    parser.add_argument("-S", "--SUMMARY", help='summarize the process in a table', action="store_true")
+    parser.add_argument("-T", "--taxids", help='write a text file listing all the accession numbers and their related TaxIDs', action="store_true")
+    parser.add_argument("-S", "--summary", help='summarize the process in a table', action="store_true")
     #Taxonomy
     group3 = parser.add_mutually_exclusive_group()
     group3.add_argument("-i", "--information", help="just add the taxonomic information in the information line of the output file(s)", action="store_true" )
